0.9.9 API documentation: vector_double4.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_double4.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_vec4.hpp"
6
7 namespace glm
8 {
11
15 typedef vec<4, double, defaultp> dvec4;
16
18 }//namespace glm
glm::dvec4
vec< 4, double, defaultp > dvec4
4 components vector of double-precision floating-point numbers.
Definition: vector_double4.hpp:15
glm
Definition: common.hpp:20